##==========================================================================================##
## Replication File for
##   "Perceptions of Deservingness and the Politicization of Social Insurance"
##   Albert H. Fang and Gregory A. Huber
##   Accepted for publication at American Politics Research
##
## June 30, 2019
##==========================================================================================##

rm(list=ls(all=TRUE))

# Install packages if not yet installed
list.of.packages <- c("estimatr", "stargazer", "ggridges", "ggrepel", "foreign", "coefplot",
                      "xtable", "scales", "reshape2", "weights", "rio", "multcomp", "broom", "tidyverse")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)

# Load packages
library(estimatr)
library(stargazer)
library(ggridges)
library(ggrepel)
library(foreign)
library(coefplot)
library(xtable)
library(scales)
library(reshape2)
library(weights)
library(rio)
library(multcomp)
library(broom)
library(tidyverse)

# Set working directory
#setwd("~/Dropbox/S_SSDIDeservingness/ReplicationFiles/")
setwd("C:/Users/wujen/Dropbox/S_WuHuber/RATasks/archives to check/_To Publish/60 Public Files")

##----------------------------------------##
## LOAD/PREP DATA, LOAD HELPER FUNCTIONS
##----------------------------------------##

## Load Data Files

# CCES team module
cces <- read.csv("data_cces_module.csv", header=TRUE, stringsAsFactors=FALSE, strip.white=TRUE)
# Lucid 2017 survey
lucid17 <- read.csv("data_lucid17.csv", header=TRUE, stringsAsFactors=FALSE, strip.white=TRUE)
# Lucid 2019 survey
lucid19 <- read.csv("data_lucid19.csv", header=TRUE, stringsAsFactors=FALSE, strip.white=TRUE)

## Load helper functions
source("code_helperfunctions.R")

## Prep data before analysis
source("code_prepdata.R")

##----------------------------------------##
## TABLES AND FIGURES: MAIN TEXT
##----------------------------------------##

## Table 1 -- Reported Knowledge and Perception of Other SSDI Benefit Recipients (dataframe: cces)
source("code_table1_panel1.R")
source("code_table1_panel2.R")

## Figure 1 -- Perceptions of Percentage of SSDI Recipients Who Are Able to Work But Do Not Want To Work (dataframe: cces)
source("code_figure1.R")

## Figure 2 -- Mean Agreement with Gov Decision to Grant SSDI to Recipient, by Impairment (dataframe: cces)
source("code_figure2.R")

## Figure 3 -- Mean Deservingness Perceptions, by Impairment and Recipient Race (dataframe: lucid19)
source("code_figure3.R")

## Figure 4 -- Informational Appeals and SSDI Program Attitudes (dataframe: cces)
source("code_figure4.R")

##----------------------------------------##
## TABLES AND FIGURES: ONLINE APPENDIX
##----------------------------------------##

## Table A1 -- Summary Statistics, CCES Module Sample (page A-9)
## Note: This code reads in the CCES Common Content file (CCES16_Common_OUTPUT_Jul2017_VV.dta)
source("code_tableA1.R")

## Table A2 -- Summary Statistics, Lucid 2017 Sample (page A-11)
source("code_tableA2.R")

## Figure A1 -- Perceptions of the Percentage of SSDI Recipients Who are Able and Want to Work, But Are Unable to Find Suitable Employment / CCES module data (page A-13)
source("code_figureA1.R")

## Figure A2 -- Perceptions of the Percentage of SSDI Recipients with Other Given Characteristics / CCES module data (page A-14)
source("code_figureA2.R")

## Table A3 -- Party ID and Perceptions of the Share of SSDI Recipients Who Can But Do Not Want to Work / CCES module data (page A-15)
source("code_tableA3.R")

## Table A4 -- Reported Knowledge of Other SSDI Benefit Recipients and Beliefs about Deservingness / Lucid 2017 data (page A-16)
## Table A5 -- Reported Knowledge of Other SSDI Benefit Recipients and Beliefs about their Ability to Work / Lucid 2017 sample (page A-17)
source("code_tableA4_tableA5.R")

## Table A6 -- Beliefs about the Average SSDI Recipient / Lucid 2017 sample (page A-18)
source("code_tableA6.R")

## Table A7 -- Party ID and Beliefs about the Average SSDI Recipient / Lucid 2017 sample (page A-18)
source("code_tableA7.R")

## Table A8 -- Mean Agreement w Gov Decision to Grant Benefits to Recipient, by Impairment and Subject's PID / CCES module (page A-20)
source("code_tableA8.R")

## Table A9 -- Impairment Effects on Agreement / CCES module (page A-21)
source("code_tableA9.R")

## Figure A3 -- Mean Agreement w Gov Decision to Grant Benefits to Recipient, by Impairment and Subject Ideology / CCES module (page A-22)
source("code_figureA3.R")

## Table A10 -- Mean Agreement w Gov Decision to Grant Benefits to Recipient, by Impairment and Subject Ideology / CCES module (page A-23)
source("code_tableA10.R")

## Table A11 -- Heterogeneous Effects, by Party ID, of Impairment on Agreement w Gov Decision / CCES module (page A-24)
source("code_tableA11.R")

## Table A12 -- Effect of Info Appeals on Program Attitudes / CCES module (page A-25)
source("code_tableA12.R")

## Table A13 -- Effect of Any Risk Pooling or Any Costly Program Appeal / CCES module (page A-26)
source("code_tableA13.R")

## Table A14 -- Effect of Appeals about SSDI on Other Attitudes about SSDI / CCES module (page A-27)
source("code_tableA14.R")

## Table A15 -- Effect of Any Risk Pooling or Any Costly Program Appeal, by Party ID / CCES module (page A-28)
source("code_tableA15.R")

## Figure A4 -- Perception of Percent of Program Beneficiaries with Given Traits by PID, Passing Attn Checks / Lucid 19 data (page A-32)
## Figure A6 -- Perception of Percent of Program Beneficiaries with Given Traits by PID, No Sample Restriction / Lucid 19 data (page A-35)
source("code_figureA4_figureA6.R")

## Figure A5 -- Modal Perception of Pct of Program Beneficiaries with Given Traits by PID, Passing Attn Checks / Lucid 19 data (page A-33)
source("code_figureA5.R")

## Table A16 -- Partisan Diffs in the Perceived Pct of Beneficiaries with a Given Trait, Passing Attn Checks / Lucid 19 data (page A-34)
source("code_tableA16.R")

## Table A17 -- Partisan Diffs in the Perceived Pct of Beneficiaries with a Given Trait, No Sample Restriction / Lucid 19 data (page A-36)
source("code_tableA17.R")

## Figure A7 -- ATE of Recipient Impairment; ATE of Recipient Race on Perceived Deservingness / Lucid 19 data (page A-38)
source("code_figureA7.R")

## Figure A8 -- Mean Deservingness Perception by Recipient Impairment and Subject PID / Lucid 19 data (page A-39)
source("code_figureA8.R")

## Table A18 -- Impairment Effects on Perceived Deservingness, by Subject PID / Lucid 19 data (page A-39)
source("code_tableA18.R")

## Figure A9 -- Mean Deservingness Perception by Recipient Race and Subject PID / Lucid 19 data (page A-40)
source("code_figureA9.R")

## Table A19 -- Recipient Race Effects on Perceived Deservingness, by Subject PID / Lucid 19 data (page A-40)
source("code_tableA19.R")

##----------------------------------------##
## OTHER ANALYSES REPORTED IN MAIN TEXT
##----------------------------------------##

## Randomization Checks --- for experiments embedded in the CCES team module
source("code_randchecks.R")

