## HELPER FUNCTIONS

trim <- function (x) gsub("^\\s+|\\s+$", "", x)

ylim_range <- c(-2,2)

# Diverging 5-category colours 
green_purple_diverging5cat <- c("#d01c8b",
                                "#f1b6da",
                                "#cccccc",
                                "#b8e186",
                                "#4dac26")

groupMeans <- function(df, byvars, vars) {
  
  require(dplyr)
  
  b1 <- lapply(c(byvars), as.symbol)
  
  group_means <- df[,c(byvars, vars)] %>%
    group_by_(.dots = b1) %>%
    summarise_all(funs(mean(., na.rm=TRUE)))
  
  group_variances <- df[,c(byvars, vars)] %>%
    group_by_(.dots = b1) %>%
    summarise_all(funs(var(., na.rm=TRUE)))
  
  group_ns <- df[,c(byvars, vars)] %>%
    group_by_(.dots = b1) %>%
    summarise_all(funs(length(.)))
  
  x0 <- left_join(group_means, group_variances, by=byvars)
  names(x0) <- gsub(".x", "_m", names(x0), fixed=TRUE)
  names(x0) <- gsub(".y", "_v", names(x0), fixed=TRUE)
  
  x1 <- left_join(x0, group_ns, by=byvars)
  names(x1)[(ncol(x0)+1):ncol(x1)] <- paste(names(x1)[(ncol(x0)+1):ncol(x1)], "n", sep="_")
  
  for(i in 1:length(vars)){
    x1[[ paste0(vars[i],"_se") ]] <- sqrt(x1[[ paste0(vars[i],"_v") ]])/sqrt(x1[[ paste0(vars[i],"_n") ]])
    
    
    x1[[ paste0(vars[i],"_tstar") ]] <- critical_t <- qt(0.05/2, x1[[ paste0(vars[i],"_n") ]] -1, lower.tail = FALSE)
    
    x1[[ paste0(vars[i],"_lci") ]] <- x1[[ paste0(vars[i],"_m") ]] - critical_t * x1[[ paste0(vars[i],"_se") ]]
    x1[[ paste0(vars[i],"_uci") ]] <- x1[[ paste0(vars[i],"_m") ]] + critical_t * x1[[ paste0(vars[i],"_se") ]]
  }
  
  x1 <- as.data.frame(x1)
  
  
  require(reshape2)
  
  clm <- melt(x1, id.vars=byvars)
  clm$variable <- as.character(clm$variable)
  
  clm$stat <- unlist(lapply(strsplit(clm$variable, "_", fixed=TRUE), function(J) J[length(J)]))
  clm$variable <- unlist(lapply(strsplit(clm$variable, "_", fixed=TRUE), function(J) paste(J[1], collapse="_")))
  
  fmla <- paste0(paste(c(byvars, "variable"), collapse="+"),
                 "~ stat")
  
  out <- dcast(clm, fmla, value.var="value")
  
  return(out)
}  

makeTexTable <- function(sgout, caption, label, rsboxwidth, notes, number.notes=FALSE, swaps=NULL, file=NULL){
  
  if(!is.null(swaps)){
    for(i in 1:nrow(swaps)){
      sgout <- ifelse(sgout == swaps[i,1],
                      swaps[i,2],
                      sgout)
    }
  }
  
  if(!number.notes){
    notes_line <- paste0("\\item ",notes)
  } else {
    notes_line <- paste0("\\item"," [",1:length(notes),"] ",notes)
  }
  
  out <- c("\\begin{table}[!ht]",
           "\\centering",
           paste0("\\caption{",caption,"}"),
           paste0("\\label{",label,"}"),
           paste0("\\resizebox{",rsboxwidth,"\\textwidth}{!}{"),
           "\\begin{threeparttable}[b]",
           sgout,
           "\\begin{tablenotes}",
           notes_line,
           "\\end{tablenotes}",
           "\\end{threeparttable}",
           "}",
           "\\end{table}"
  )
  
  if(!is.null(file)){
    cat(out, file=file, sep="\n")
  }
  
  return(out)
}



# Create variable name/description lookup table
var_lookup <- rbind(c("YAL345", "receive_ssdi_self"),
                    c("YAL345_order", "receive_ssdi_self_order"),
                    c("YAL346", "receive_ssdi_household"),
                    c("YAL347", "receive_ssdi_friends"),
                    c("YAL348", "receive_ssdi_extfam"),
                    c("YAL349", "receive_ssdi_community"),
                    c("YAL350", "case_vignette_decision"),
                    c("YAL350_select", "case_vignette_diagnosis"),
                    c("YAL350_order", "case_vignette_order"),
                    c("YAL409", "comp_phys_notinjury"),
                    c("YAL410", "comp_phys_injury"),
                    c("YAL411", "comp_mental_disorder"),
                    c("YAL412", "comp_intell_disab"),
                    c("YAL413", "comp_can_but_wont_work"),
                    c("YAL414", "comp_can_but_cant_find_work"),
                    c("YAL415", "comp_under65"),
                    c("YAL416", "comp_women"),
                    c("YAL417", "comp_1to2kids"),
                    c("YAL418", "comp_3pluskids"),
                    c("YAL419", "comp_white"),
                    c("YAL420", "comp_other_pub_assist"),
                    c("YAL421", "att_nonsevere_ineligible"),
                    c("YAL422", "att_ssdi_canwork_majprob"),
                    c("YAL423", "att_encourage_work_if_can"),
                    c("YAL424", "att_allow_earnmore_incthres"),
                    c("YAL425", "att_require_employer_prov"),
                    c("YAL426", "att_fedgov_spendtoomuch"),
                    c("YAL421_select", "att_ssdi_appeal"))

### Functions to calculate and output summary statistics

sumstats_continuous <- function(df, x) {
  
  v <- df[[x]]
  v_mean <- mean(v, na.rm=TRUE)
  v_sd <- sd(v, na.rm=TRUE)
  v_n <- length(v)
  v_se <- v_sd / sqrt(v_n)
  
  v_mean <- sprintf("%.3f", round(v_mean, 3))
  v_se <- paste0("(", sprintf("%.3f", round(v_se, 3)),")")
  
  out <- c(x, x, v_mean, v_se)
  names(out) <- c("Variable", "Covariate", "Mean", "(SE)")
  return(out)
  
}

sumstats_categorical <- function(df, x) {
  
  v <- df[[x]]
  v_n <- length(v)
  v_numer <- table(v)
  v_denom <- sum(v_numer)
  v_pct <- v_numer / v_denom 
  
  v_se <- NULL
  for(i in 1:length(v_pct)){
    v_se[i] <- sqrt(v_pct[i] * (1 - v_pct[i]) / v_n)
  }
  
  v_pct <- sprintf("%.3f", round(v_pct, 3))
  v_se <- paste0("(", sprintf("%.3f", round(v_se, 3)) ,")")
  
  out <- cbind(x, names(v_numer), v_pct, v_se)
  colnames(out) <- c("Variable", "Covariate", "Mean", "(SE)")
  rownames(out) <- NULL
  return(out)
  
}



### Helper functions for analysis of data from Lucid 2019 survey 


## Re-create default ggplot colors
gg_color_hue <- function(n) {
  hues = seq(15, 375, length = n + 1)
  hcl(h = hues, l = 65, c = 100)[1:n]
}

## Function to find the mode
Mode <- function(x) {
  ux <- unique(x)
  ux[which.max(tabulate(match(x, ux)))]
}

